# dbnd-examples

This package contains examples used by dbnd users to see dbnd capabilities and functionality

## Installation

This package can not be installed as a python module because of examples/data folder.
All data inside this folder is not embedded into the package.
